//
//  ViewController.m
//  AnimationTest
//
//  Created by Derek Cannon on 3/23/12.
//  Copyright (c) 2012 __MyCompanyName__. All rights reserved.
//

#import <QuartzCore/QuartzCore.h>
#import "ViewController.h"


// This is defined in Math.h
#define M_PI   3.14159265358979323846264338327950288   /* pi */

// Our conversion definition
#define DEGREES_TO_RADIANS(angle) (angle / 180.0 * M_PI)


@interface ViewController ()

@end

@implementation ViewController
@synthesize gear1;
@synthesize gear2;
@synthesize gear3;
@synthesize cannon;
@synthesize animatedGear;

NSArray *myImages;

- (void)viewDidLoad
{
    [super viewDidLoad];
	// Do any additional setup after loading the view, typically from a nib.
	
	[self runSpinAnimationOnView:gear1 duration:1.0 rotations:0.15 repeat:-1 clockwise:YES];
	[self runSpinAnimationOnView:gear2 duration:1.0 rotations:1 repeat:-1 clockwise:NO];
	[self runSpinAnimationOnView:gear3 duration:1.0 rotations:0.4 repeat:-1 clockwise:YES];
	
	cannon.layer.anchorPoint = CGPointMake(0.5, 0.85); // move the center point of rotation
	
	// Frame-by-frame animation test:
	
	myImages = [NSArray arrayWithObjects:
				[UIImage imageNamed:@"gear.png"],
				[UIImage imageNamed:@"gear2.png"],
				[UIImage imageNamed:@"gear3.png"], nil];
	
	animatedGear.animationImages = myImages;
	animatedGear.animationDuration = 0.25;
	animatedGear.animationRepeatCount = HUGE_VALF;
	[animatedGear startAnimating];
	
	// Add rotation to the frame-by-frame, for fun
	[self runSpinAnimationOnView:animatedGear duration:1.0 rotations:0.4 repeat:-1 clockwise:YES];
	
}

- (void) runSpinAnimationOnView:(UIView*)view duration:(CGFloat)duration rotations:(CGFloat)rotations repeat:(float)repeat clockwise:(bool)clockwise;
{
    CABasicAnimation* rotationAnimation;
    rotationAnimation = [CABasicAnimation animationWithKeyPath:@"transform.rotation.z"];
    rotationAnimation.toValue = [NSNumber numberWithFloat: M_PI * 2.0 /* full rotation*/ * rotations * duration * (clockwise ? 1 : -1) ];
    rotationAnimation.duration = duration;
    rotationAnimation.cumulative = YES; 
	rotationAnimation.repeatCount = (repeat == -1 ? HUGE_VALF : repeat);
	
    [view.layer addAnimation:rotationAnimation forKey:@"rotationAnimation"];
}

- (void)viewDidUnload
{
	[self setGear1:nil];
	[self setGear2:nil];
	[self setGear3:nil];
	[self setCannon:nil];
	[self setAnimatedGear:nil];
    [super viewDidUnload];
    // Release any retained subviews of the main view.
}

-(void) touchesMoved:(NSSet *)touches withEvent:(UIEvent *)event
{
	UITouch *touch = [touches anyObject];
	CGPoint touchPoint = [touch locationInView:self.view];
	
	float dy = cannon.frame.origin.y - touchPoint.y;
	float dx = cannon.frame.origin.x - touchPoint.x;
	
	cannon.transform = CGAffineTransformMakeRotation(atan2(dy,dx) - DEGREES_TO_RADIANS(95)); //+ DEGREES_TO_RADIANS(-180));
}

- (BOOL)shouldAutorotateToInterfaceOrientation:(UIInterfaceOrientation)interfaceOrientation
{
	if ([[UIDevice currentDevice] userInterfaceIdiom] == UIUserInterfaceIdiomPhone) {
	    return (interfaceOrientation != UIInterfaceOrientationPortraitUpsideDown);
	} else {
	    return YES;
	}
}

@end
